@@ -7,7 +7,7 @@
 
 #define QT_FEATURE_webengine_v8_context_snapshot 1
 
-#define QT_FEATURE_webengine_system_pulseaudio -1
+#define QT_FEATURE_webengine_system_pulseaudio 1
 
 #define QT_FEATURE_webengine_system_gbm 1
 
